@@ -21,6 +21,7 @@
  *
  */
 
+#include <stdlib.h>
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
@@ -268,7 +269,7 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 
 	rfcommEntry =  gtk_spin_button_new_with_range( 1, 10, 1);
 	if (rfcomm) {
-		gtk_entry_set_text(GTK_ENTRY(rfcommEntry), rfcomm);
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(rfcommEntry), atoi(rfcomm));
 	}
 	gtk_table_attach_defaults( GTK_TABLE(table), rfcommEntry, 1, 2, 2, 3);
 
@@ -300,7 +301,7 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 			/* Set string variable */
 			gconf_client_set_string(gc_client, GNOKII_GCONF_MODEL_KEY, model, NULL);
 		}
-		rfcomm = gtk_entry_get_text(GTK_ENTRY(rfcommEntry));
+		rfcomm = g_strdup_printf("%d", gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(rfcommEntry)));
 		if (rfcomm) {
 			/* Set string variable */
 			gconf_client_set_string(gc_client, GNOKII_GCONF_RFCOMM_KEY, rfcomm, NULL);
